@@ -1813,12 +1813,14 @@ def omni_compare(val, ref):
                     )
                 }
         elif type(val) != type(ref): # different types; not both numbers
+            vt = html_tools.escape(str(type(val).__name__))
+            rt = html_tools.escape(str(type(ref).__name__))
             return {
                 "status": "failed",
                 "explanation": (
-                    f"Your result was {phrasing.a_an(str(type(val)))},"
+                    f"Your result was {phrasing.a_an(vt)},"
                     f" but the correct result was"
-                    f" {phrasing.a_an(str(type(ref)))}."
+                    f" {phrasing.a_an(rt)}."
                 )
             }
         elif isinstance(val, str): # both strings
