@@ -534,19 +534,36 @@ class Context:
         Builds an HTML representation of this context's result using the
         display_product function. A base context is required because
         create is used to fetch the current value (or build a new one).
+
+        If context creation fails, the result will be a string describing
+        the error.
         """
         try:
             return self.display_product(self.create(base_context))
         except context_utils.ContextCreationError as e:
+            tb = html_tools.html_traceback(e)
             return f"""\
 <div class="context_error">
   <h3>An error was encountered while attempting to run this test.</h3>
-<pre>
-{e}
-</pre>
+{tb}
 </div>
 """
 
+    def warnings(self, base_context):
+        """
+        Returns a list of HTML strings representing warnings generated by
+        this context. A base context is required because we need to
+        generate the context value to see if there are warnings, although
+        a cached value will be used in most cases. Returns an empty list
+        when no warnings have been generated.
+        """
+        try:
+            ctx = self.create(base_context)
+            return ctx.get("warnings", [])
+        except context_utils.ContextCreationError as e:
+            tb = html_tools.html_traceback(e)
+            return [ f"Error during context creation:<br>{tb}" ]
+
 
 def add_context_numbering(all_context_objs):
     """
@@ -712,7 +729,13 @@ def list_and_render_contexts(cgraph, base_context=None):
         produced by this context. This will be the result of the
         context's display_product function run on the most recent result
         of that context (or on a fresh result if caching is disabled for
-        the context).
+        the context). There may be a description of a context creation
+        error here if there is an error building the context value.
+    - warnings: A list of strings indicating context-based rather than
+        test-based warnings. In general contexts should only create
+        warnings in very specific circumstances, since tests are
+        responsible for most warnings, and might want to ignore issues
+        that a context could warn about.
 
     The base_context argument is used to generate context results (will
     only happen if cached results are not available or caching is
@@ -750,9 +773,10 @@ def list_and_render_contexts(cgraph, base_context=None):
 
     # Iterate over all nodes in order
     for cnode in nodeslist:
+        ctx = cnode["context"]
         result.append(
             {
-                "description": cnode["context"].html_topic(
+                "description": ctx.html_topic(
                     base_context is not None
                 ),
                 "depends": [
@@ -761,10 +785,14 @@ def list_and_render_contexts(cgraph, base_context=None):
                 ],
                 "level": cnode["level"],
                 "value": (
-                    cnode["context"].html_representation(base_context)
+                    ctx.html_representation(base_context)
                     if base_context is not None
                     else ""
                 ),
+                "warnings": (
+                    ctx.warnings(base_context)
+                    if base_context is not None else []
+                )
             }
         )
 
@@ -1128,7 +1156,14 @@ class CodeContext(AutoContext):
                     cause=e
                 )
 
-            return {
+            if node is None:
+                raise context_utils.ContextCreationError(
+                    self,
+                    f"Unable to parse submitted file '{filename}'.",
+                    cause=errors[0]
+                )
+
+            result = {
                 "original_source": original_source,
                 "source": fixed,
                 "scope": node,
@@ -1136,6 +1171,21 @@ class CodeContext(AutoContext):
                 "parse_errors": errors
             }
 
+            # Report parsing issues as warnings
+            if errors:
+                result["warnings"] = [
+                    (
+                        "The following errors were encountered when parsing"
+                      + " your code:<br>"
+                      + html_tools.build_list(
+                            html_tools.html_traceback(e)
+                            for e in errors
+                        )
+                    )
+                ]
+
+            return result
+
         # Figure out if we need to use automatic dependencies:
         if depends is None:
             depends = auto("filename", "file_path")
