@@ -587,13 +587,13 @@ def rewrite_traceback_filenames(raw_traceback, prefix_map=None):
     return result
 
 
-def function_def_code_tags(fn_name, args_pattern, announce=None):
+def function_def_code_tags(fn_name, params_pattern, announce=None):
     """
     Returns a tuple containing two strings of HTML code used to represent
     the given function definition in both short and long formats. The
     short format just lists the first acceptable definition, while the
     long format lists all of them. Note that both fn_name and
-    args_pattern may be lists of strings instead of strings; see
+    params_pattern may be lists of strings instead of strings; see
     function_def_patterns.
     """
     if isinstance(fn_name, str):
@@ -601,11 +601,11 @@ def function_def_code_tags(fn_name, args_pattern, announce=None):
     else:
         names = list(fn_name)
 
-    # If there are specific args we can give users more info about what
-    # they need to do.
-    if isinstance(args_pattern, str):
+    # If there are specific parameters we can give users more info about
+    # what they need to do.
+    if isinstance(params_pattern, str):
         specific_names = [
-            "{}({})".format(name, args_pattern) for name in names
+            "{}({})".format(name, params_pattern) for name in names
         ]
     else:
         specific_names = names
@@ -621,11 +621,11 @@ def function_def_code_tags(fn_name, args_pattern, announce=None):
         junction="or"
     )
 
-    # Add a comment about the number of arguments required
-    if isinstance(args_pattern, int):
+    # Add a comment about the number of parameters required
+    if isinstance(params_pattern, int):
         with_n = " with {} {}".format(
-            args_pattern,
-            phrasing.plural(args_pattern, "argument")
+            params_pattern,
+            phrasing.plural(params_pattern, "parameter")
         )
         code_tag += with_n
         details_code += with_n
