@@ -237,7 +237,7 @@ window.addEventListener("load", function () {
                     for (
                         let row
                      of document.querySelectorAll(
-                         "div.rubric_row.status_accomplished:not(.tag_category)"
+                     "div.rubric_row.status_accomplished:not(.goal_category)"
                         )
                     ) {
                         row.style.display = "none";
@@ -246,7 +246,7 @@ window.addEventListener("load", function () {
                     for (
                         let row
                      of document.querySelectorAll(
-                         "div.rubric_row.status_accomplished:not(.tag_category)"
+                     "div.rubric_row.status_accomplished:not(.goal_category)"
                         )
                     ) {
                         row.style.display = "block";
@@ -254,6 +254,16 @@ window.addEventListener("load", function () {
                 }
             }
         );
+        if (hide_accomplished.checked) {
+            for (
+                let row
+             of document.querySelectorAll(
+                    "div.rubric_row.status_accomplished:not(.goal_category)"
+                )
+            ) {
+                row.style.display = "none";
+            }
+        }
     }
 });
 
