@@ -475,7 +475,7 @@ class Snippet(specifications.TestGroup):
                 "Error captured by context creation:\n"
               + context["error"]
               + "\nFull log is:\n"
-              + context["error_log"]
+              + context.get("error_log", '<missing>')
             )
         result = self.render_context(context)
         for glammer in self.glammers:
