@@ -9,7 +9,7 @@ from potluck import specifications as spec
 
 # We want to run the file and see what happens
 base_cases = [
-    spec.TestCase("__import__")
+    spec.TestImport()
         .provide_inputs(inputs, policy="hold")
         .set_context_description(
             (
@@ -34,7 +34,7 @@ base_cases = [
 ]
 
 
-base = spec.group("__import__").test_output(capture_errors=True)
+base = spec.group("import").test_output(capture_errors=True)
 
 base.refine(
     spec.Find,
