@@ -194,7 +194,7 @@ meta.expect("failed", "behavior", "core", "correct indentation")
 meta.expect("failed", "behavior", "extra", "correct output")
 meta.expect("partial", "testing", "core", "defines required")
 meta.expect("partial", "testing", "extra", "were met")
-meta.expect("partial", "testing", "extra", "are correct")
+meta.expect("partial", "testing", "additional", "are correct")
 
 
 # Snippets for the instructions
